<!--
  This file is auto-generated by the Scalar README generator.
  Command: pnpm --filter @scalar-internal/build-scripts start generate-readme
  
  Do not edit this file manually. Changes will be lost when the file is regenerated.
-->

# Scalar API Reference Plugin for Django Ninja

[![Version](https://img.shields.io/pypi/v/scalar-ninja)](https://pypi.org/project/scalar-ninja/)
[![Downloads](https://img.shields.io/pypi/dm/scalar-ninja)](https://pypi.org/project/scalar-ninja/)
[![License](https://img.shields.io/pypi/l/scalar-ninja)](https://pypi.org/project/scalar-ninja/)
[![Discord](https://img.shields.io/discord/1135330207960678410?style=flat&color=5865F2)](https://discord.gg/scalar)

Scalar Django Ninja integration

## Documentation

[Read the documentation here](https://scalar.com/products/api-references/integrations/django-ninja)

## Changelog

See [CHANGELOG.md](https://github.com/scalar/scalar/blob/main/integrations/django-ninja/CHANGELOG.md) for a list of changes.

## Community

We are API nerds. You too? Let’s chat on Discord: <https://discord.gg/scalar>

## License

The source code in this repository is licensed under [MIT](https://github.com/scalar/scalar/blob/main/LICENSE).
